summaryrefslogtreecommitdiffstats
path: root/kpilot/kpilot/fileInstaller.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kpilot/kpilot/fileInstaller.cc')
-rw-r--r--kpilot/kpilot/fileInstaller.cc36
1 files changed, 18 insertions, 18 deletions
diff --git a/kpilot/kpilot/fileInstaller.cc b/kpilot/kpilot/fileInstaller.cc
index 6c26a79f..d46c67d2 100644
--- a/kpilot/kpilot/fileInstaller.cc
+++ b/kpilot/kpilot/fileInstaller.cc
@@ -34,9 +34,9 @@
#include <unistd.h>
-#include <qstring.h>
-#include <qstrlist.h>
-#include <qdir.h>
+#include <tqstring.h>
+#include <tqstrlist.h>
+#include <tqdir.h>
#include <kglobal.h>
#include <kstandarddirs.h>
@@ -69,13 +69,13 @@ void FileInstaller::clearPending()
unsigned int i;
- QDir installDir(fDirName);
+ TQDir installDir(fDirName);
// Start from 2 to skip . and ..
//
for (i = 2; i < installDir.count(); i++)
{
- QFile::remove(fDirName + installDir[i]);
+ TQFile::remove(fDirName + installDir[i]);
}
if (i > 2)
@@ -84,24 +84,24 @@ void FileInstaller::clearPending()
}
}
-void FileInstaller::deleteFile(const QString &file)
+void FileInstaller::deleteFile(const TQString &file)
{
- QFile::remove(fDirName + file);
+ TQFile::remove(fDirName + file);
emit filesChanged();
}
-void FileInstaller::deleteFiles(const QStringList &files)
+void FileInstaller::deleteFiles(const TQStringList &files)
{
if(files.empty())
return;
- for(QStringList::ConstIterator it = files.begin(); it != files.end(); ++it)
- QFile::remove(fDirName + *it);
+ for(TQStringList::ConstIterator it = files.begin(); it != files.end(); ++it)
+ TQFile::remove(fDirName + *it);
emit filesChanged();
}
/* virtual */ bool FileInstaller::runCopy(const QString & s, QWidget* w )
{
FUNCTIONSETUP;
@@ -127,7 +127,7 @@ void FileInstaller::deleteFiles(const QStringList &files)
}
-void FileInstaller::addFiles(const QStringList & fileList, QWidget* w)
+void FileInstaller::addFiles(const TQStringList & fileList, TQWidget* w)
{
FUNCTIONSETUP;
@@ -135,7 +135,7 @@ void FileInstaller::addFiles(const QStringList & fileList, QWidget* w)
unsigned int succ = 0;
- for(QStringList::ConstIterator it = fileList.begin();
+ for(TQStringList::ConstIterator it = fileList.begin();
it != fileList.end(); ++it)
{
if (runCopy( *it, w ))
@@ -148,7 +148,7 @@ void FileInstaller::addFiles(const QStringList & fileList, QWidget* w)
}
}
-void FileInstaller::addFile( const QString & file, QWidget* w )
+void FileInstaller::addFile( const TQString & file, TQWidget* w )
{
FUNCTIONSETUP;
@@ -165,14 +165,14 @@ void FileInstaller::addFile( const QString & file, QWidget* w )
FUNCTIONSETUP;
}
-const QStringList FileInstaller::fileNames() const
+const TQStringList FileInstaller::fileNames() const
{
FUNCTIONSETUP;
- QDir installDir(fDirName);
+ TQDir installDir(fDirName);
- return installDir.entryList(QDir::Files |
- QDir::NoSymLinks | QDir::Readable);
+ return installDir.entryList(TQDir::Files |
+ TQDir::NoSymLinks | TQDir::Readable);
}
/* slot */ void FileInstaller::setEnabled(bool b)
@@ -84,24 +84,24 @@ void FileInstaller::clearPending()
emit filesChanged();
}
-/* virtual */ bool FileInstaller::runCopy(const QString & s, QWidget* w )
+/* virtual */ bool FileInstaller::runCopy(const TQString & s, TQWidget* w )
{
FUNCTIONSETUP;